#!/bin/bash

opt=""
io=""
cnt=0
error=0
help=0

while [[ $# > 0 ]]
do
key="$1"

case $key in
    -t|--show-trajectories)
    opt="$opt -t"
    ;;
    -h|--help)
    help=1
    ;;
    *)
    ((cnt=$cnt+1))
    if [[ ! -e $key ]]
    then
	error=1
	msg="error: unable to open file \"$key\"."
    fi
    input_traj=$key
    ;;
esac
shift # past argument or value
done

function display_usage
{
    echo "usage: tview.py [-h] [-t] file"
    echo "  file (mandatory argument)          : The file containing the points and trajectories"
    echo "  -h, --help (optional)              : display help message"
    echo "  -t, --show-trajectories (optional) : Draw trajectories when displaying the sequence"
}

function display_help
{
    echo "Interactive keys:"
    echo "  q   : Quit"
    echo "  +/- : Zoom in/out"
    echo "  f/b : Go forward or backward in the sequence"
    echo "  <n>g: Goto frame n (eg 45g)"
    echo "  t   : Toggle trajectory drawing (when trajectories have been loaded)"
    echo "  m   : Set the current frame as the first frame from which to draw trajectories"
    echo "  h   : Highlight the points that belong to a trajectory in red"
    echo "  x   : Randomize the trajectory colors"
}

if [[ $help -eq 1 ]]
then
    display_usage
    echo " "
    display_help
elif [[ $error -eq 1 ]]
then
    echo $msg
elif [[ $cnt -ne 1 ]]
then
    display_usage
    echo "error: invalid number of arguments."
else
    rdm=$RANDOM
    ((nx=1+`cut -d " " -f 2 $input_traj | sort -n | tail -n 1`))
    ((ny=1+`cut -d " " -f 3 $input_traj | sort -n | tail -n 1`))
    echo "type = PointsFile v.1.0" > /tmp/__reshaped_tview_input_$rdm
    echo "uid = 1" >> /tmp/__reshaped_tview_input_$rdm
    echo "width = $nx" >> /tmp/__reshaped_tview_input_$rdm
    echo "height = $ny" >> /tmp/__reshaped_tview_input_$rdm
    echo "DATA ">> /tmp/__reshaped_tview_input_$rdm
    cat $input_traj >> /tmp/__reshaped_tview_input_$rdm
    DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )
    $DIR/python/tview.py $opt /tmp/__reshaped_tview_input_$rdm
    \rm /tmp/__reshaped_tview_input_$rdm
fi


